package com.ym.mec.biz.dal.dto;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;

import javax.validation.constraints.Email;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;
import java.io.Serializable;

/**
 * @author hgw
 * Created by 2021-12-02
 */
@ApiModel(value = "机构参数")
public class TenantInfoDto implements Serializable {

    private static final long serialVersionUID = 1L;

    /**
     * 机构id
     */
    @ApiModelProperty(value = "机构id")
    private Integer id;

    /**
     * 机构名称
     */
    @NotBlank(message = "机构名称不能为空")
    @Size(max = 50, message = "机构名称长度不能超过50!")
    @ApiModelProperty(value = "机构名称")
    private String name;

    /**
     * 机构联系人
     */
    @NotBlank(message = "机构联系人不能为空")
    @Size(max = 14, message = "机构联系人长度不能超过14!")
    @ApiModelProperty(value = "机构联系人")
    private String contacts;

    /**
     * 机构联系人电话
     */
    @NotBlank(message = "机构联系人电话不能为空!")
    @Size(max = 13, message = "联系人电话手机号最高11位，座机号最高为13位,请核实后在填写!")
    @Pattern(regexp = "^[0-9|-]*$", message = "联系人电话只能填写数字")
    @ApiModelProperty(value = "机构联系人电话")
    private String phone;

    /**
     * 地址
     */
    @NotBlank(message = "地址不能为空!")
    @Size(max = 200, message = "地址长度不能超过200个字!")
    @ApiModelProperty(value = "地址")
    private String address;

    /**
     * 机构邮箱
     */
    @NotBlank(message = "邮箱不能为空!")
    @Email(message = "邮箱格式不正确！")
    @Size(max = 64, message = "邮箱长度不能超过64位!")
    @ApiModelProperty(value = "机构邮箱")
    private String email;

    /**
     * 机构logo
     */
    @ApiModelProperty(value = "机构logo")
    private String logo;

    /**
     * 客服电话
     */
    @NotBlank(message = "客服电话不能为空!")
    @Size(max = 13, message = "客服电话电话-手机号最高11位、座机号最高为13位,请核实后再填写!")
    @Pattern(regexp = "^[0-9]*$", message = "客服电话电话只能填写数字！")
    @ApiModelProperty(value = "客服电话")
    private String customerServicePhone;

    /**
     * 域名
     */
    @ApiModelProperty(value = "域名")
    private String domainName;

    /**
     * 数据源
     */
    @ApiModelProperty(value = "数据源")
    private String dataSource;


    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getContacts() {
        return contacts;
    }

    public void setContacts(String contacts) {
        this.contacts = contacts;
    }

    public String getPhone() {
        return phone;
    }

    public void setPhone(String phone) {
        this.phone = phone;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getEmail() {
        return email;
    }

    public void setEmail(String email) {
        this.email = email;
    }

    public String getLogo() {
        return logo;
    }

    public void setLogo(String logo) {
        this.logo = logo;
    }

    public String getCustomerServicePhone() {
        return customerServicePhone;
    }

    public void setCustomerServicePhone(String customerServicePhone) {
        this.customerServicePhone = customerServicePhone;
    }

    public String getDomainName() {
        return domainName;
    }

    public void setDomainName(String domainName) {
        this.domainName = domainName;
    }

    public String getDataSource() {
        return dataSource;
    }

    public void setDataSource(String dataSource) {
        this.dataSource = dataSource;
    }
}
